DTEDMetadata

Struct DTEDMetadata 

pub struct DTEDMetadata {
    pub filename: String,
    pub origin: AxisElement<f64>,
    pub origin_angle: AxisElement<Angle>,
    pub interval: AxisElement<f64>,
    pub interval_secs: AxisElement<f32>,
    pub accuracy: Option<u16>,
    pub count: AxisElement<u16>,
}
DTED metadata

Fields

  • filename - filename
  • origin - position of the lower left corner of the grid (floating point precision)
  • origin_angle - position of the lower left corner of the grid
  • interval - interval (floating point precision)
  • interval_secs - interval (as seconds of an Angle)
  • accuracy - absolute vertical accuracy in meters (with 90% assurance that the linear errors will not exceed this value relative to mean sea level)
  • count - number of longitude lines and latitude points

Fields

filename: Stringorigin: AxisElement<f64>origin_angle: AxisElement<Angle>interval: AxisElement<f64>interval_secs: AxisElement<f32>accuracy: Option<u16>count: AxisElement<u16>

Implementations

Source

impl DTEDMetadata

pub fn from_header(raw: &RawDTEDHeader, fname: &str) -> DTEDMetadata

Create a DTEDMetadata from a RawDTEDHeader

Arguments
Returns